/**
 * WildCAT
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Master.java 333 2008-09-04 17:28:48Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.examples.cluster;

import java.util.concurrent.TimeUnit;

import net.esper.client.UpdateListener;
import net.esper.event.EventBean;

import org.ow2.wildcat.Context;
import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.ContextFactory;

/**
 * Launch an embedded JORAM Server and demonstrate the use of CMI by performing some pulls on a remote context ({@link Slave}).
 * @author Loris Bouzonnet
 */
public class Master {

	/**
	 * @param args
	 */
	public static void main(final String[] args) {
		ContextFactory contextFactory = new ContextFactory(
				Thread.currentThread().getContextClassLoader().getResource("wildcat-master.properties"));
		Context ctx = contextFactory.createContext();
		try {
			ctx.export();
		} catch (ContextException e1) {
			// TODO Auto-generated catch block
			e1.printStackTrace();
		}
		ctx.registerListeners("select * from WEvent", new UpdateListener() {
			public void update(final EventBean[] arg0, final EventBean[] arg1) {
				for(EventBean bean : arg0) {
					System.out.println("---> " + bean.getUnderlying().toString());
				}
			}
		});
		// Wait the slave to make some pulls
		while(!contextFactory.isRemoteContextAvailable("slave")) {
			try {
				Thread.sleep(10000);
			} catch (InterruptedException e) {
				Thread.currentThread().interrupt();
			}
		}
		System.out.println("Slave is available!");

		try {
			ctx.createSymlink("self://slave", "slave://");
		} catch (ContextException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		try {
			ctx.createAttribute("slave://proc/cpu#load", 12);
			ctx.setValue("self://slave/proc/cpu#load", 33);
			ctx.createPeriodicAttributePoller("slave://proc/cpu#load", 2, TimeUnit.SECONDS);
		} catch (ContextException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

}
