/**
 *	This file is part of org.ow2.wildcat.
 *
 *	wildcat is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	wildcat is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 */
package org.ow2.wildcat.remote.dispatcher;

import javax.jms.Topic;
import javax.jms.TopicPublisher;

import org.ow2.wildcat.Context;

/**
 * Wrap an exported context with its associated {@link Topic} and {@link TopicPublisher}.
 */
public class Export {

	/**
	 * The exported context.
	 */
	private final Context context;

	/**
	 * Topic to publish.
	 */
	private final Topic topic;

	/**
	 * Publisher of events thrown by this context.
	 */
	private final TopicPublisher publisher;


	public Export(
			final Context context, final Topic topic, final TopicPublisher publisher) {
		this.context = context;
		this.topic = topic;
		this.publisher = publisher;
	}

	public Context getContext() {
		return this.context;
	}

	public TopicPublisher getPublisher() {
		return this.publisher;
	}

	protected final Topic getTopic() {
		return topic;
	}

}
