/**
 * WildCAT
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RMIRemoteContext.java 334 2008-09-05 17:14:19Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.wildcat.remote.dispatcher.rmi;

import java.rmi.Remote;
import java.rmi.RemoteException;

import javax.jms.Topic;
import javax.jms.TopicConnectionFactory;

import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.remote.RemoteContext;


/**
 * Define a way to retrieve the topic and topic connection factory created by this context.
 * @author Loris Bouzonnet
 */
public interface RMIRemoteContext extends Remote, RemoteContext {

	/**
	 * @return the topic used by this context to emit its events
	 * @throws RemoteException if the connection failed
	 * @throws ContextException if the topic cannot be retrieved
	 */
	Topic getTopicToSpy() throws RemoteException, ContextException;

	/**
	 * @return the topic connection factory to create a listener of this context
	 * @throws RemoteException if the connection failed
	 * @throws ContextException if the topic connection factory cannot be retrieved
	 */
	TopicConnectionFactory getTopicConnectionFactoryToSpy() throws RemoteException, ContextException;

}
