/**
 * WildCAT
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JMSProvider.java 328 2008-09-03 09:15:47Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.wildcat.remote.provider;

import javax.jms.Queue;
import javax.jms.QueueConnectionFactory;
import javax.jms.Topic;
import javax.jms.TopicConnectionFactory;

import org.ow2.wildcat.ContextFactory;

/**
 * Interface to define different manners of getting a JMS Provider.
 * @author Loris Bouzonnet
 */
public interface JMSProvider {

    /**
     * Initialize a JMS provider with the given properties.
     * @param props some properties
     * @throws JMSProviderException if the initialization failed
     */
    void init(ContextFactory contextFactory) throws JMSProviderException;

    /**
     * @return a topic connection factory
     * @throws JMSProviderException if a topic connection factory cannot be retrieved
     */
    TopicConnectionFactory getTopicConnectionFactory() throws JMSProviderException;

    /**
     * @return a queue connection factory
     * @throws JMSProviderException if a queue connection factory cannot be retrieved
     */
    QueueConnectionFactory getQueueConnectionFactory() throws JMSProviderException;

    /**
     * @param topicName a topic name
     * @return a topic with the given name
     * @throws JMSProviderException if a topic with the given name cannot be retrieved
     */
    Topic getTopic(String topicName) throws JMSProviderException;

    /**
     * @param queueName a queue name
     * @return a queue with the given name
     * @throws JMSProviderException if a queue with the given name cannot be retrieved
     */
    Queue getQueue(String queueName) throws JMSProviderException;

    void deleteTopic(String topicName) throws JMSProviderException;

    void deleteQueue(String queueName) throws JMSProviderException;

    /**
     * Destroy the JMS provider.
     */
    void destroy() throws JMSProviderException;

}
