/**
 *	This file is part of org.ow2.wildcat.
 *
 *	wildcat is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	wildcat is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 */
package org.ow2.wildcat.sensors;

import java.text.ParseException;
import java.util.HashMap;
import java.util.Map;

/**
 * CPU Info sensor. Sample informations from "/proc/cpuinfo"
 */
public final class CPUInfoSensor extends TextFileSensor implements Sensor {

	/**
	 * Id for serializable class.
	 */
	private static final long serialVersionUID = -4876635381240076523L;

	/**
	 * Default constructor
	 */
	public CPUInfoSensor() {
		super("/proc/cpuinfo");
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see org.ow2.wildcat.sensors.TextFileSensor#getValues(java.lang.String[])
	 */
	@Override
	protected Map<String, Object> getValues(final String[] lines) {
		Map<String, Object> samples = new HashMap<String, Object>();
		for (int i = 0; i < LINE_FORMATS.length; i++) {
			String name = LINE_FORMATS[i].getProperty();
			Object value = null;
			try {
				value = ((Object[]) LINE_FORMATS[i].getFormat().parseObject(
						lines[i]))[0];
			} catch (ParseException e) {
				// ignore and continue
			}
			if (value instanceof Number) {
				samples.put(name, value);
			} else if (value instanceof String) {
				samples.put(name, value);
			} else if (value instanceof Boolean) {
				samples.put(name, value);
			} else {
				throw new RuntimeException("Should not happen.");
			}
		}
		return samples;
	}

	private static final LineFormat[] LINE_FORMATS = new LineFormat[] {
		new LineFormat("processor", "processor\t: {0,number,integer}"),
		new LineFormat("vendor_id", "vendor_id\t: {0}"),
		new LineFormat("cpu_family", "cpu family\t: {0,number,integer}"),
		new LineFormat("model", "model\t\t: {0,number,integer}"),
		new LineFormat("model_name", "model name\t: {0}"),
		new LineFormat("stepping", "stepping\t: {0,number,integer}"),
		new LineFormat("speed", "cpu MHz\t\t: {0,number}"),
		new LineFormat("cache", "cache size\t: {0,number,integer} KB") };
}
