/**
 *	This file is part of org.ow2.wildcat.
 *
 *	wildcat is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	wildcat is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 */
package org.ow2.wildcat.sensors;

import java.text.MessageFormat;
import java.text.ParsePosition;
import java.util.HashMap;
import java.util.Map;

/**
 * CPU load sensors. Data are sampled from the /proc/cpu#loadavg file. It
 * exposes 3 fields avg1, avg5, avg15, average load over the 1 respectively 5
 * and 15 seconds.
 */
public final class CPULoadSensor extends TextFileSensor implements Sensor {

	/**
	 * Id for serializable class.
	 */
	private static final long serialVersionUID = 7148272476654277269L;

	/**
	 * Default Constructor
	 */
	public CPULoadSensor() {
		super("/proc/loadavg");
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see org.ow2.wildcat.sensors.TextFileSensor#getValues(java.lang.String[])
	 */
	@Override
	protected Map<String, Object> getValues(final String[] lines) {
		Map<String, Object> samples = new HashMap<String, Object>();
		Object[] loads = FORMAT.parse(lines[0], new ParsePosition(0));
		samples.put("avg1", new Double((String) loads[0]));
		samples.put("avg5", new Double((String) loads[1]));
		samples.put("avg15", new Double((String) loads[2]));
		return samples;
	}

	private static MessageFormat FORMAT = new MessageFormat("{0} {1} {2} {3}");
}
