/**
 *	This file is part of org.ow2.wildcat.
 *
 *	wildcat is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	wildcat is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 */
package org.ow2.wildcat.sensors;

import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;

import org.ow2.wildcat.hierarchy.attribute.POJOAttribute;
import org.ow2.wildcat.util.TimeUtil;

/**
 * DateTimeSensor, exposes date and time from the JVM
 */
public final class DateTimeSensor extends POJOAttribute implements Sensor {

	/**
	 * Id for serializable class.
	 */
	private static final long serialVersionUID = -6196480285614902379L;

	private static final Calendar cal = Calendar.getInstance();

	/**
	 * Default constructor
	 */
	public DateTimeSensor() {
		super(null);
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see org.ow2.wildcat.hierarchy.attribute.POJOAttribute#getValue()
	 */
	@Override
	public Object getValue() {
		Map<String, Object> samples = new HashMap<String, Object>();
		long now = TimeUtil.now();
		cal.setTimeInMillis(now);
		samples.put("now", TimeUtil.format(now));
		samples.put("hour", cal.get(Calendar.HOUR));
		samples.put("minute", cal.get(Calendar.MINUTE));
		samples.put("second", cal.get(Calendar.SECOND));
		samples.put("time", now);
		return samples;
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see dirtycat.hierarchy.BasicAttribute#setValue(java.lang.Object)
	 */
	@Override
	public Object setValue(final Object value) {
		return super.setValue(this.value);
	}
}
