/**
 *	This file is part of org.ow2.wildcat.
 *
 *	wildcat is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	wildcat is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 */
package org.ow2.wildcat.sensors;

import java.util.HashMap;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * A Factory/Manager for Sensors
 */
public class SensorLibrary {

	private static Log logger = LogFactory.getLog(SensorLibrary.class);

	/**
	 * Default SensorLibrary. Reference every sensors
	 */
	public static SensorLibrary DEFAULT;

	static {
		try {
			DEFAULT = new SensorLibrary();
			DEFAULT.library.put("CPUInfo", CPUInfoSensor.class);
			DEFAULT.library.put("CPULoad", CPULoadSensor.class);
			DEFAULT.library.put("DateTime", DateTimeSensor.class);
			DEFAULT.library.put("JavaRuntime", JavaRuntimeSensor.class);
			DEFAULT.library.put("KernelVersion", KernelVersionSensor.class);
			DEFAULT.library.put("Null", NullSensor.class);
			DEFAULT.library.put("SystemProperties",
					SystemPropertiesSensor.class);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	private Map<String, Class<? extends Sensor>> library;

	public SensorLibrary() {
		this.library = new HashMap<String, Class<? extends Sensor>>();
	}

	public boolean contains(final String sensor) {
		return this.library.containsKey(sensor);
	}

	/**
	 * Instantiate a Sensor
	 *
	 * @param sensor
	 *            sensor's name
	 * @return a new Sensor of type "sensor", or a new NullSensor if sensor
	 *         can't be resolved
	 */
	public Sensor instanciate(final String sensor) {
		try {
			return this.library.get(sensor).newInstance();
		} catch (Exception e) {
			logger.info("Failled instanciating sensor '" + sensor + "'", e);
			return new NullSensor();
		}
	}
}
