/**
 *	This file is part of org.ow2.wildcat.
 *
 *	wildcat is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	wildcat is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 */
package org.ow2.wildcat.sensors;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Properties;

import org.ow2.wildcat.hierarchy.attribute.POJOAttribute;

/**
 * SystemPropertiesSensor exposes the System.getProperties() object
 */
public class SystemPropertiesSensor extends POJOAttribute implements Sensor {

	/**
	 * Id for serializable class.
	 */
	private static final long serialVersionUID = 2497368052933488176L;

	/**
	 * Default constructor
	 */
	public SystemPropertiesSensor() {
		super(null);
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see org.ow2.wildcat.hierarchy.attribute.POJOAttribute#getValue()
	 */
	@Override
	public Object getValue() {
		Map<String, Object> samples = new HashMap<String, Object>();
		Properties prop = System.getProperties();
		for (Iterator<Object> iter = prop.keySet().iterator(); iter.hasNext();) {
			String name = (String) iter.next();
			samples.put(name, prop.getProperty(name));
		}
		return samples;
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see org.ow2.wildcat.hierarchy.attribute.POJOAttribute#setValue(java.lang.Object)
	 */
	@Override
	public Object setValue(final Object value) {
		return super.setValue(this.value);
	}
}
