/**
 *	This file is part of org.ow2.wildcat.
 *
 *	wildcat is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	wildcat is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 */
package org.ow2.wildcat.util;

import org.ow2.wildcat.hierarchy.Path;

/**
 * Helper class, it contains static methods primarly used inside Esper requests
 */
public final class Helper {

	/**
	 * Test that path starts with the given prefix
	 *
	 * @param path
	 *            the Path to test prefix against
	 * @param prefix
	 *            the prefix to test
	 * @return <b>true</b> if both path and prefix are valid finite paths and
	 *         path starts with prefix, else <b>false</b>
	 */
	public static boolean isPrefix(final String path, final String prefix) {
		try {
			Path pa = new Path(path);
			Path pr = new Path(prefix);

			pa.expectAbsolute();
			pr.expectAbsolute();
			pa.expectCanonical();
			pr.expectCanonical();
			pa.expectFinite();
			pr.expectFinite();

			pr.expectResource();

			return pa.isPrefix(pr);
		} catch (Exception e) {
			return false;
		}
	}
}
