/**
 *	This file is part of org.ow2.wildcat.
 *
 *	wildcat is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	wildcat is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 */
package org.ow2.wildcat.hierarchy;

import org.ow2.wildcat.Context;
import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.ContextFactory;
import org.testng.Assert;
import org.testng.annotations.Test;

/**
 * Unit test for pull mode operations on {@link org.ow2.wildcat.Context}
 */
public class TestPull {

	private Context context = null;

	/**
	 * Initialize a context
	 * @throws ContextException
	 */
	public TestPull() throws ContextException {
		this.context = ContextFactory.getDefaultFactory().createContext();
		this.context.createAttribute("self://test#attribute", 17);
		this.context.createAttribute("self://test#hello", "Hello");
		this.context.createSymlink("self://symlink", "self://test");
	}

	/**
	 * Test method for
	 * {@link org.ow2.wildcat.Context#getValue(java.lang.String)}.
	 * @throws ContextException
	 */
	@Test
	public void testGetValue() throws ContextException {
		Object attr = this.context.getValue("self://test#attribute");
		Assert.assertTrue(attr instanceof Integer);
		Assert.assertTrue(17 == (Integer) attr);
	}

	/**
	 * Test method for
	 * {@link org.ow2.wildcat.Context#getValue(java.lang.String)}.
	 * @throws ContextException
	 */
	@Test
	public void testGetValueThroughSymlink() throws ContextException {
		Object attr = this.context.getValue("self://symlink#attribute");
		Assert.assertTrue(attr instanceof Integer);
		Assert.assertTrue(17 == (Integer) attr);
	}

	/**
	 * Test method for
	 * {@link org.ow2.wildcat.Context#setValue(java.lang.String)}.
	 * @throws ContextException
	 */
	@Test
	public void testSetValue() throws ContextException {
		Object oo = this.context.setValue("self://test#hello",
		"Hello World !!!");
		Assert.assertTrue(oo instanceof String);
		Assert.assertTrue("Hello".equals(oo));

		Object nn = this.context.getValue("self://test#hello");
		Assert.assertTrue(nn instanceof String);
		Assert.assertTrue("Hello World !!!".equals(nn));
	}

	/**
	 * Test method for {@link org.ow2.wildcat.Context#list(java.lang.String)}.
	 * @throws ContextException
	 */
	@Test
	public void testList() throws ContextException {
		Assert.assertTrue(this.context.list("self://test").size() == 2);
	}
}
